
# Loren Williams, Georgia Tech
# pymol script for tRNA

## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 3

## End of Header: General Commands ##
#----------------------------------------

load files/yeast_phe_1trna.pdb, tRNA

set cartoon_ring_mode=3, tRNA
set cartoon_tube_radius=0.6, tRNA
hide everything, all
show cartoon, tRNA

#  make the xyz axis
create axis, resn axe
show stick, axis
label axis and name XT, "X"
label axis and name YT, "Y"
label axis and name ZT, "Z"
set label_color, black, axis 
delete axis

# color the bases

#color red, (resn ADE or resn A) and (tRNA)
#color blue, (resn URA or resn U) and (tRNA)
#color forest, (resn CYT or resn C) and (tRNA)
# color violetpurple, (resn GUA or resn G) and (tRNA)

#-------------color the RNA by location in secondary structure

#--ACCA
color black, resi 73-77

#--acceptor stem
color blue, resi 1-7 or resi 66-72

#--D stem
color red, resi 8-26

#--anticodon Stem
color tv_green, resi 27-43

#--V loop
color purple, resi 44-48

#--T Stem
color gray60, resi 49-65
#color purple, (tRNA and name O5*,O3*,P,O1P,O2P) and resi 49-65



#--------------- Label the stems 
create Acceptor_Stem, name U and resn lab
create Anticodon_Stem, name V and resn lab
create D_Stem, name D and resn lab
create T_Stem, name T and resn lab
create CCA, name CCA and resn lab

label Acceptor_Stem, "Acceptor Stem"
label Anticodon_Stem, "Anticodon Stem"
label D_Stem, "D Stem"
label T_Stem, "T Stem"
label CCA, "CCA"


set label_size, -2
set label_color, blue, Acceptor_Stem
set label_color, tv_green, Anticodon_Stem
set label_color, red, D_Stem
set label_color, black, T_Stem
set label_color, black, CCA
set label_color, wheat, tRNA

#---------------------------4-69 Wobble

create wobble_4_69, resi 4+69 and tRNA
distance HB_wobble, resi 4, resi 69, 3.2
show stick, wobble*

#---------------------------anticodon
create anticodon, resi 34-36 and tRNA
hide everything, anticodon
show stick, anticodon
color yellow, resi 34-36 and tRNA

label resi 35 and name N1 and tRNA, "Anticodon"
set label_position,(3,0,0), tRNA
set label_size, -2, tRNA 


label resi 34 and name N1 and anticodon, "wobble position"
set label_position,(2,0,0), anticodon
set label_size, -1, anticodon 

#---------------------------base triples

create triple_9_23_12, resi 9+23+12 and tRNA
distance HB_9_23_12, resi 9+12, resi 23, 3.2

create triple_25_10_45, resi 25+10+45 and tRNA
distance HB_25_10_45, resi 10, resi 25+45, 3.2

create triple_13_22_46, resi 13+22+46 and tRNA
distance HB_13_22_46, resi 22, resi 13+46, 3.0

show stick, triple_*

#---------------------------U33 Hbond
show sphere, resi 33 and name N3
show sphere, resi 36 and name O1P
color blue, resi 33 and name N3
color red, resi 36 and name O1P
set sphere_scale, 0.25
distance uturn, resi 33 and name N3, resi 36 and name O1P
set label_size, -0.5, uturn
color black, uturn

set label_size, -0.5, uturn
color black, uturn
set dash_width, 9, uturn
set dash_gap, .1, uturn
set dash_length, .05, uturn
set label_position, (0,1,0), uturn


set label_size, -0.5, HB_*
color black, HB_*
set dash_width, 7, HB_*
set dash_gap, .2, HB_*
set label_position, (0,1,0), HB_*

set label_color, red
set label_font_id, 7

disable all
enable tRNA
enable Acceptor_Stem
enable Anticodon_Stem
enable D_Stem 
enable T_Stem
enable CCA
enable anticodon

color wheat, name C* and (wobble_* or triple_* or anticodon)
color red, name O* and (wobble_* or triple_* or anticodon)
color blue, name N* and (wobble_* or triple_* or anticodon)
color yellow, name P* and (wobble_* or triple_* or anticodon)


# standard view

set_view (\
    -0.721729994,   -0.074827932,   -0.688120782,\
    -0.610960126,    0.536118627,    0.582500935,\
     0.325328171,    0.840818346,   -0.432650864,\
    -0.000012185,   -0.000014976, -234.881805420,\
    35.388671875,   -8.146804810,   27.208419800,\
   185.133895874,  284.610107422,    0.000000000 )
### cut above here and paste into script ### 

# remove the # from two lines below to make an image 
# ray 2000, 2000
# save trna_1b.png
